@@ -18,6 +18,19 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifndef __SCIM_ANTHY_SETUP_KANA_H__
+#define __SCIM_ANTHY_SETUP_KANA_H__
+
+#ifdef HAVE_CONFIG_H
+  #include <config.h>
+#endif
+
+#include <gtk/gtk.h>
+
+#define Uses_SCIM_CONFIG_BASE
+#include <scim.h>
+
+
 namespace scim_anthy {
 
 GtkWidget *kana_page_create_ui     (void);
@@ -26,3 +39,5 @@ void       kana_page_save_config   (const ConfigPointer &config);
 bool       kana_page_query_changed (void);
 
 };
+
+#endif /* __SCIM_ANTHY_SETUP_KANA_H__ */
